@@ -2,7 +2,7 @@
  * drv_suse.c: the suse backend for suse
  *
  * Copyright (C) 2010 Novell Inc.
- * Copyright (C) 2009 Red Hat Inc.
+ * Copyright (C) 2009-2012 Red Hat Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -42,6 +42,7 @@
 #include "ref.h"
 #include "list.h"
 #include "dutil.h"
+#include "dutil_posix.h"
 #include "dutil_linux.h"
 
 #include <libxml/parser.h>
@@ -1008,6 +1009,8 @@ struct netcf_if *drv_define(struct netcf *ncf, const char *xml_str) {
     int r;
     struct augeas *aug = get_augeas(ncf);
 
+    ERR_BAIL(ncf);
+
     ncf_xml = parse_xml(ncf, xml_str);
     ERR_BAIL(ncf);
 
@@ -1174,6 +1177,9 @@ int drv_if_up(struct netcf_if *nif) {
     }
     run1(ncf, ifup, nif->name);
     ERR_BAIL(ncf);
+    ERR_THROW(!if_is_active(ncf, nif->name), ncf, EOTHER,
+              "interface %s failed to become active - "
+              "possible disconnected cable.", nif->name);
     result = 0;
  error:
     free_matches(nslaves, &slaves);
